@@ -2,6 +2,7 @@
 #'
 #' Internal function used to process scores and replace outliers.
 #'
+#' @noRd
 #' @param data Data set.
 #' @param scores Matrix with outlier scores.
 #' @param predData Prediction data.frame.
@@ -14,7 +15,7 @@
 #' @param max_prop_outliers max_prop_outliers.
 #' @param allow_predictions allow_predictions.
 #' @param obj outForest object.
-#' @return A list.
+#' @returns A list.
 process_scores <- function(data, scores, predData, v, rmse, replace, pmm.k, threshold,
                            max_n_outliers, max_prop_outliers, allow_predictions,
                            obj = NULL) {
@@ -24,7 +25,7 @@ process_scores <- function(data, scores, predData, v, rmse, replace, pmm.k, thre
     # Bound outlier count
     max_n_outliers <- min(max_n_outliers, max_prop_outliers * nrow(data) * length(v))
     if (sum(is_outlier) > max_n_outliers) {
-      threshold <- sort(abs(scores[is_outlier]), decreasing = TRUE)[max_n_outliers + 1]
+      threshold <- sort(abs(scores[is_outlier]), decreasing = TRUE)[max_n_outliers + 1L]
       is_outlier <- abs(scores) > threshold
     }
 
@@ -80,5 +81,3 @@ process_scores <- function(data, scores, predData, v, rmse, replace, pmm.k, thre
     rmse = rmse
   )
 }
-
-
